@@ -12,15 +12,10 @@ class FX(ReapyObject):
 
     _class_name = "FX"
 
-    _functions: Dict[str, Callable[..., Any]] = {}
+    _functions: Dict[str, Dict[str, Callable[..., Any]]] = {}
 
-    # @property
-    def _get_functions(self) -> Dict[str, Callable[..., Any]]:
-        print('generating functions')
-        if isinstance(self.parent, reapy_boost.Track):
-            type_ = "TrackFX_"
-        else:
-            type_ = "TakeFX_"
+    @staticmethod
+    def _get_cls_functions() -> Dict[str, Dict[str, Callable[..., Any]]]:
         return {
             prefix: {
                 name.replace(prefix, ""): function
@@ -28,7 +23,7 @@ class FX(ReapyObject):
                 if name.startswith(prefix)
             }
             for prefix in ("TrackFX_", "TakeFX_")
-        }[type_]
+        }
 
     def __init__(
         self,
@@ -42,13 +37,17 @@ class FX(ReapyObject):
         parent_id = parent.id
         self.parent_id = parent_id
         self.index = index
+        self.functions = self._get_functions()
 
-    @property
-    def functions(self) -> Dict[str, Callable[..., Any]]:
+    def _get_functions(self) -> Dict[str, Callable[..., Any]]:
         cls = self.__class__
         if not cls._functions:
-            cls._functions = self._get_functions()
-        return self._functions
+            cls._functions = self._get_cls_functions()
+        if isinstance(self.parent, reapy_boost.Track):
+            type_ = "TrackFX_"
+        else:
+            type_ = "TakeFX_"
+        return cls._functions[type_]
 
     # def _get_functions(self) -> Dict[str, Callable[..., Any]]:
     #     if isinstance(self.parent, reapy_boost.Track):
